"use client";
import FormButtons from "@/components/simulation/common/form-buttons";
import Sidebar from "@/components/simulation/common/sidebar";
import { ImageBaseUrl } from "@/configs/api";
import { selectPoolTile } from "@/servers/actions/pool-request-action";
import { useProduct } from "@/servers/data/use-product";
import { useTranslations } from "next-intl";
import dynamic from "next/dynamic";
import { useRouter, useSearchParams } from "next/navigation";
import React, { useState, useTransition } from "react";
import { toast } from "sonner";
const Scene = dynamic(() => import("@/components/swimming-pool/scene"));


const DefaultSelect = { pool: 1, showWater: true, floor: 1, ladder: 0, waterfall: 0, jacuzzi: 0, lamp: 0, selectedTile: null, selectedLadder: null };

export default function PoolTiles() {
	const t = useTranslations();
	const router = useRouter();
	const searchParams = useSearchParams();
	const [showItem, setShowItem] = useState<any>(DefaultSelect);
	const [isPending, startTransition] = useTransition();

	// Fetch tiles products
	const { products: tilesProducts, isLoading } = useProduct({ product_type: "tile" });


	// Update showItem based on URL parameters
	React.useEffect(() => {
		const pool = searchParams.get("pool");
		if (pool) {
			setShowItem((prev: typeof DefaultSelect) => ({ ...prev, pool: parseInt(pool) }));
		}

		const tile = searchParams.get("tile");
		if (tile) {
			setShowItem((prev: typeof DefaultSelect) => ({ ...prev, selectedTile: { id: parseInt(tile) } }));
		}
	}, [searchParams]);

	React.useEffect(() => {
		if (tilesProducts?.data?.length > 0) {
			setShowItem((prev: typeof DefaultSelect) => ({ ...prev, selectedTile: { id: tilesProducts?.data[0]?.id, texture: tilesProducts?.data[0]?.texture, model_3d: tilesProducts?.data[0]?.model_3d } }));
		}
	}, [tilesProducts]);

	const _tiles: any = React.useMemo(() => ({
		title: t("Type of tiles"),
		path: "tile",
		images: tilesProducts?.data?.map((product: any) => ({
			src: ImageBaseUrl + product?.texture,
			alt: product?.name_en,
			data: {
				selectedTile: {
					id: product?.id,
					texture: product?.texture,
					model_3d: product?.model_3d
				}
			}
		})) || [],
		position: {
			position: { "x": 0.8903247283818498, "y": 1.2028714978985868, "z": -0.9091121057509381 },
			target: { "x": -0.4259998874210678, "y": -0.7593486953557362, "z": 0.49184718640933445 }
		}
	}), [t, tilesProducts]);

	console.log("showItem", showItem);
	const handleNextPage = async () => {
		if (showItem.selectedTile?.id) {
			const response = await selectPoolTile(showItem.selectedTile?.id);
			console.log("response: ", response);
			if (!response.success) {
				toast.error(response.message);
			}
		}

		startTransition(() => {
			router.push(`/simulation-program/pool-ladders?pool=${showItem.pool}&tile=${showItem.selectedTile?.id}` as any);
		});
	};

	return (
		<div className="h-screen w-full start-bg">
			<div className="flex h-full">
				<div className="w-full flex items-center justify-center">
					{showItem.selectedTile?.id &&
						<FormButtons
							onPrevious={() => router.back()}
							onNext={handleNextPage}
							isPending={isPending}
						/>
					}
					<Scene showItem={showItem} cameraSetting={_tiles?.position} />
					<Sidebar
						title={_tiles?.title}
						images={_tiles?.images}
						setShowItem={setShowItem}
						showItem={showItem}
						isLoading={isLoading}
					/>
				</div>
			</div>
		</div>
	);
}
